==> haskell-warp-3.3.15-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 warp
version:              3.3.15
visibility:           public
id:                   warp-3.3.15-7VrPFTMpS0GH0u9qJdlNhP
key:                  warp-3.3.15-7VrPFTMpS0GH0u9qJdlNhP
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  d959b58a741e928e3e659835e8cf8568
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
    Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-8.10.4/site-local/warp-3.3.15
library-dirs:         /usr/lib/ghc-8.10.4/site-local/warp-3.3.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/warp-3.3.15
hs-libraries:         HSwarp-3.3.15-7VrPFTMpS0GH0u9qJdlNhP
depends:
    array-0.5.4.0 async-2.2.3-DvF9gf9qyfPK6D6feIe45y
    auto-update-0.1.6-8Ty0Syqt41GvhFO81OhV3 base-4.14.1.0
    bsb-http-chunked-0.0.0.4-FNXeUsYSuJDGn8ofpVd77j
    bytestring-0.10.12.0
    case-insensitive-1.2.1.0-3NIW57P40JN584hTPPyqOm containers-0.6.2.1
    ghc-prim-0.6.1 hashable-1.3.2.0-5x51STP8vZMKBx9J0CoY3R
    http-date-0.0.11-5fsFNb6ummGLHavJ6uT4iO
    http-types-0.12.3-COhfNYEpiaQFi7TclzTcwh
    http2-3.0.1-8GxRTZZuOkCG6pRKopHN0V
    iproute-1.7.11-DdAowF1Jj6KFeSiqqdL93d
    network-3.1.2.1-JWsgyzxIkceBMW0wbRjAeX
    simple-sendfile-0.2.30-FUzKBxAKMdBBB9eGsbjjGU stm-2.5.0.0
    streaming-commons-0.2.2.1-GjQsXMHNgfKCVB2kbeUr0B text-1.2.4.1
    time-manager-0.0.0-IXTQBv6wMEzFRM5xDQtQ1s unix-2.7.2.2
    unix-compat-0.5.3-E98n0JyMac7Bz478oqWJHX
    vault-0.3.1.5-L5jFnawvX5X64hUfbu0vHj
    wai-3.2.3-3IMRzNOMwP69fSq5qEgh7E word8-0.1.3-724fxDOkAtI9odHi3S4RPp
    x509-1.7.5-139C7ACasha6Vz9hIAJC2w

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-3.3.16-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 warp
version:              3.3.16
visibility:           public
id:                   warp-3.3.16-Elsb3MmV6iH2O1pxz2JDXX
key:                  warp-3.3.16-Elsb3MmV6iH2O1pxz2JDXX
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  22daa5c69b802cf2cf9703830794d6c2
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
    Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-8.10.4/site-local/warp-3.3.16
library-dirs:         /usr/lib/ghc-8.10.4/site-local/warp-3.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/warp-3.3.16
hs-libraries:         HSwarp-3.3.16-Elsb3MmV6iH2O1pxz2JDXX
depends:
    array-0.5.4.0 auto-update-0.1.6-3W5hzT3Q89k2Z8S8wpDT9U
    base-4.14.1.0 bsb-http-chunked-0.0.0.4-5SlUvBSPuWs9qwWCVX8lNB
    bytestring-0.10.12.0
    case-insensitive-1.2.1.0-3NIW57P40JN584hTPPyqOm containers-0.6.2.1
    ghc-prim-0.6.1 hashable-1.3.2.0-5x51STP8vZMKBx9J0CoY3R
    http-date-0.0.11-F61fuNJCUVa5uFwIm4bIHX
    http-types-0.12.3-IkaWRXxGlShL2hy1dv5IKX
    http2-3.0.1-LiNiQoDwdGw9Duk1iUEU3u
    iproute-1.7.11-G52Qk8RuJUP8raglT1rVXO
    network-3.1.2.1-1Gyf5UCYFs3AQp4EITpwv3
    simple-sendfile-0.2.30-CC4owLqsZlXJu5venUE1ry stm-2.5.0.0
    streaming-commons-0.2.2.1-CNuQPTa1O4PLWM6dqxNN1O text-1.2.4.1
    time-manager-0.0.0-GcZW6GWCOSLDujU0kuQc6D unix-2.7.2.2
    unix-compat-0.5.3-E98n0JyMac7Bz478oqWJHX
    unliftio-0.2.17-Es6AwiYBEBqHiGmQFfyEYD
    vault-0.3.1.5-3AKl3xbqYevJv89fNYCWub
    wai-3.2.3-GGxlbYYrnI7JwwgOVoB7i3 word8-0.1.3-724fxDOkAtI9odHi3S4RPp
    x509-1.7.5-Pip3wg4TnSFD5LpyLCL0v

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
